@@ -1,5 +1,4 @@
 
-from concurrent import futures
 from subprocess import CompletedProcess
 
 import abstracts
@@ -13,10 +12,6 @@ class AsyncShell:
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-    @property
-    def executor(self) -> futures.Executor:
-        return super().executor
-
     def parallel(self, *args, **kwargs) -> "functional.AwaitableGenerator":
         return super().parallel(*args, **kwargs)
 
